@@ -4,6 +4,7 @@ require_relative '../lib/gitlab_access_status'
 
 describe GitlabShell do
   before do
+    $logger = double('logger').as_null_object
     FileUtils.mkdir_p(tmp_repos_path)
   end
 
@@ -31,7 +32,7 @@ describe GitlabShell do
 
   let(:api) do
     double(GitlabNet).tap do |api|
-      api.stub(discover: { 'name' => 'John Doe' })
+      api.stub(discover: { 'name' => 'John Doe', 'username' => 'testuser' })
       api.stub(check_access: GitAccessStatus.new(
                 true,
                 'ok',
@@ -167,7 +168,7 @@ describe GitlabShell do
 
       it "should use usernames if configured to do so" do
         GitlabConfig.any_instance.stub(audit_usernames: true)
-        $logger.should_receive(:info).with("executing git command", hash_including(user: 'John Doe'))
+        $logger.should_receive(:info).with("executing git command", hash_including(user: 'testuser'))
       end
     end
 
@@ -202,7 +203,7 @@ describe GitlabShell do
 
       it "should use usernames if configured to do so" do
         GitlabConfig.any_instance.stub(audit_usernames: true)
-        $logger.should_receive(:info).with("executing git command", hash_including(user: 'John Doe'))
+        $logger.should_receive(:info).with("executing git command", hash_including(user: 'testuser'))
       end
     end
 
@@ -248,7 +249,7 @@ describe GitlabShell do
 
       it "should use usernames if configured to do so" do
         GitlabConfig.any_instance.stub(audit_usernames: true)
-        $logger.should_receive(:info).with("executing git command", hash_including(user: 'John Doe'))
+        $logger.should_receive(:info).with("executing git command", hash_including(user: 'testuser'))
       end
     end
 
@@ -275,7 +276,7 @@ describe GitlabShell do
 
       it "should use usernames if configured to do so" do
         GitlabConfig.any_instance.stub(audit_usernames: true)
-        $logger.should_receive(:info).with("executing git command", hash_including(user: 'John Doe'))
+        $logger.should_receive(:info).with("executing git command", hash_including(user: 'testuser'))
       end
     end
 
@@ -428,7 +429,7 @@ describe GitlabShell do
 
         it "refuses to assign the path" do
           $stderr.should_receive(:puts).with("GitLab: Invalid repository path")
-          expect(subject.exec(ssh_cmd)).to be_false
+          expect(subject.exec(ssh_cmd)).to be_falsey
         end
       end
     end
@@ -452,7 +453,7 @@ describe GitlabShell do
     before do
       Kernel.stub(:exec)
       shell.gl_repository = gl_repository
-      shell.username = gl_username
+      shell.instance_variable_set(:@username, gl_username)
     end
 
     it "uses Kernel::exec method" do
